Interface: ChartArea | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ChartArea

## # Properties

### # bottom

• bottom: `number`

#### # Defined in

geometric.d.ts:5
(opens new window)

### # height

• height: `number`

#### # Defined in

geometric.d.ts:7
(opens new window)

### # left

• left: `number`

#### # Defined in

geometric.d.ts:3
(opens new window)

### # right

• right: `number`

#### # Defined in

geometric.d.ts:4
(opens new window)

### # top

• top: `number`

#### # Defined in

geometric.d.ts:2
(opens new window)

### # width

• width: `number`

#### # Defined in

geometric.d.ts:6
(opens new window)